from enum import Enum


class FlawdbApiV1FlawsListMitigatedBy(str, Enum):
    FORTIFY = "FORTIFY"
    GRSEC = "GRSEC"
    SELINUX = "SELINUX"

    def __str__(self) -> str:
        return str(self.value)



import datetime
from typing import Any, Dict, List, Optional, Union

import httpx

from ...client import AuthenticatedClient
from ...models.flawdb_api_v1_flaws_list_format import FlawdbApiV1FlawsListFormat
from ...models.flawdb_api_v1_flaws_list_impact import FlawdbApiV1FlawsListImpact
from ...models.flawdb_api_v1_flaws_list_mitigated_by import FlawdbApiV1FlawsListMitigatedBy
from ...models.flawdb_api_v1_flaws_list_source import FlawdbApiV1FlawsListSource
from ...models.flawdb_api_v1_flaws_list_state import FlawdbApiV1FlawsListState
from ...models.flawdb_api_v1_flaws_list_type import FlawdbApiV1FlawsListType
from ...models.paginated_flaw_list import PaginatedFlawList
from ...types import UNSET, Response, Unset


def _get_kwargs(
    *,
    client: AuthenticatedClient,
    bz_id: Union[Unset, None, float] = UNSET,
    changed_after: Union[Unset, None, datetime.datetime] = UNSET,
    changed_before: Union[Unset, None, datetime.datetime] = UNSET,
    created_dt: Union[Unset, None, datetime.datetime] = UNSET,
    cve_id: Union[Unset, None, List[str]] = UNSET,
    cvss2: Union[Unset, None, str] = UNSET,
    cvss2_score: Union[Unset, None, float] = UNSET,
    cvss3: Union[Unset, None, str] = UNSET,
    cvss3_score: Union[Unset, None, float] = UNSET,
    cwe_id: Union[Unset, None, str] = UNSET,
    description: Union[Unset, None, str] = UNSET,
    embargoed: Union[Unset, None, bool] = UNSET,
    exclude_fields: Union[Unset, None, List[str]] = UNSET,
    flaw_meta_type: Union[Unset, None, List[str]] = UNSET,
    format_: Union[Unset, None, FlawdbApiV1FlawsListFormat] = UNSET,
    impact: Union[Unset, None, FlawdbApiV1FlawsListImpact] = UNSET,
    include_fields: Union[Unset, None, List[str]] = UNSET,
    include_meta_attr: Union[Unset, None, List[str]] = UNSET,
    limit: Union[Unset, None, int] = UNSET,
    mitigated_by: Union[Unset, None, FlawdbApiV1FlawsListMitigatedBy] = UNSET,
    offset: Union[Unset, None, int] = UNSET,
    reported_dt: Union[Unset, None, datetime.datetime] = UNSET,
    resolution: Union[Unset, None, str] = UNSET,
    search: Union[Unset, None, str] = UNSET,
    source: Union[Unset, None, FlawdbApiV1FlawsListSource] = UNSET,
    state: Union[Unset, None, FlawdbApiV1FlawsListState] = UNSET,
    statement: Union[Unset, None, str] = UNSET,
    summary: Union[Unset, None, str] = UNSET,
    title: Union[Unset, None, str] = UNSET,
    tracker_ids: Union[Unset, None, List[str]] = UNSET,
    type: Union[Unset, None, FlawdbApiV1FlawsListType] = UNSET,
    unembargo_dt: Union[Unset, None, datetime.datetime] = UNSET,
    updated_dt: Union[Unset, None, datetime.datetime] = UNSET,
    uuid: Union[Unset, None, str] = UNSET,
) -> Dict[str, Any]:
    url = "/flawdb/api/v1/flaws"

    json_changed_after: Union[Unset, None, str] = UNSET
    if not isinstance(changed_after, Unset):
        json_changed_after = changed_after.isoformat() if changed_after else None

    json_changed_before: Union[Unset, None, str] = UNSET
    if not isinstance(changed_before, Unset):
        json_changed_before = changed_before.isoformat() if changed_before else None

    json_created_dt: Union[Unset, None, str] = UNSET
    if not isinstance(created_dt, Unset):
        json_created_dt = created_dt.isoformat() if created_dt else None

    json_cve_id: Union[Unset, None, List[str]] = UNSET
    if not isinstance(cve_id, Unset):
        if cve_id is None:
            json_cve_id = None
        else:
            json_cve_id = cve_id

    json_exclude_fields: Union[Unset, None, List[str]] = UNSET
    if not isinstance(exclude_fields, Unset):
        if exclude_fields is None:
            json_exclude_fields = None
        else:
            json_exclude_fields = exclude_fields

    json_flaw_meta_type: Union[Unset, None, List[str]] = UNSET
    if not isinstance(flaw_meta_type, Unset):
        if flaw_meta_type is None:
            json_flaw_meta_type = None
        else:
            json_flaw_meta_type = flaw_meta_type

    json_format_: Union[Unset, None, str] = UNSET
    if not isinstance(format_, Unset):

        json_format_ = FlawdbApiV1FlawsListFormat(format_).value if format_ else None

    json_impact: Union[Unset, None, str] = UNSET
    if not isinstance(impact, Unset):

        json_impact = FlawdbApiV1FlawsListImpact(impact).value if impact else None

    json_include_fields: Union[Unset, None, List[str]] = UNSET
    if not isinstance(include_fields, Unset):
        if include_fields is None:
            json_include_fields = None
        else:
            json_include_fields = include_fields

    json_include_meta_attr: Union[Unset, None, List[str]] = UNSET
    if not isinstance(include_meta_attr, Unset):
        if include_meta_attr is None:
            json_include_meta_attr = None
        else:
            json_include_meta_attr = include_meta_attr

    json_mitigated_by: Union[Unset, None, str] = UNSET
    if not isinstance(mitigated_by, Unset):

        json_mitigated_by = FlawdbApiV1FlawsListMitigatedBy(mitigated_by).value if mitigated_by else None

    json_reported_dt: Union[Unset, None, str] = UNSET
    if not isinstance(reported_dt, Unset):
        json_reported_dt = reported_dt.isoformat() if reported_dt else None

    json_source: Union[Unset, None, str] = UNSET
    if not isinstance(source, Unset):

        json_source = FlawdbApiV1FlawsListSource(source).value if source else None

    json_state: Union[Unset, None, str] = UNSET
    if not isinstance(state, Unset):

        json_state = FlawdbApiV1FlawsListState(state).value if state else None

    json_tracker_ids: Union[Unset, None, List[str]] = UNSET
    if not isinstance(tracker_ids, Unset):
        if tracker_ids is None:
            json_tracker_ids = None
        else:
            json_tracker_ids = tracker_ids

    json_type: Union[Unset, None, str] = UNSET
    if not isinstance(type, Unset):

        json_type = FlawdbApiV1FlawsListType(type).value if type else None

    json_unembargo_dt: Union[Unset, None, str] = UNSET
    if not isinstance(unembargo_dt, Unset):
        json_unembargo_dt = unembargo_dt.isoformat() if unembargo_dt else None

    json_updated_dt: Union[Unset, None, str] = UNSET
    if not isinstance(updated_dt, Unset):
        json_updated_dt = updated_dt.isoformat() if updated_dt else None

    params: Dict[str, Any] = {
        "bz_id": bz_id,
        "changed_after": json_changed_after,
        "changed_before": json_changed_before,
        "created_dt": json_created_dt,
        "cve_id": json_cve_id,
        "cvss2": cvss2,
        "cvss2_score": cvss2_score,
        "cvss3": cvss3,
        "cvss3_score": cvss3_score,
        "cwe_id": cwe_id,
        "description": description,
        "embargoed": embargoed,
        "exclude_fields": json_exclude_fields,
        "flaw_meta_type": json_flaw_meta_type,
        "format": json_format_,
        "impact": json_impact,
        "include_fields": json_include_fields,
        "include_meta_attr": json_include_meta_attr,
        "limit": limit,
        "mitigated_by": json_mitigated_by,
        "offset": offset,
        "reported_dt": json_reported_dt,
        "resolution": resolution,
        "search": search,
        "source": json_source,
        "state": json_state,
        "statement": statement,
        "summary": summary,
        "title": title,
        "tracker_ids": json_tracker_ids,
        "type": json_type,
        "unembargo_dt": json_unembargo_dt,
        "updated_dt": json_updated_dt,
        "uuid": uuid,
    }
    params = {k: v for k, v in params.items() if v is not UNSET and v is not None}

    return {
        "url": url,
        "params": params,
    }


def _parse_response(*, response: httpx.Response) -> Optional[PaginatedFlawList]:
    if response.status_code == 200:
        _response_200 = response.json()
        response_200: PaginatedFlawList
        if isinstance(_response_200, Unset):
            response_200 = UNSET
        else:
            response_200 = PaginatedFlawList.from_dict(_response_200)

        return response_200
    return None


def _build_response(*, response: httpx.Response) -> Response[PaginatedFlawList]:
    return Response(
        status_code=response.status_code,
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(response=response),
    )


def sync_detailed(
    *,
    client: AuthenticatedClient,
    bz_id: Union[Unset, None, float] = UNSET,
    changed_after: Union[Unset, None, datetime.datetime] = UNSET,
    changed_before: Union[Unset, None, datetime.datetime] = UNSET,
    created_dt: Union[Unset, None, datetime.datetime] = UNSET,
    cve_id: Union[Unset, None, List[str]] = UNSET,
    cvss2: Union[Unset, None, str] = UNSET,
    cvss2_score: Union[Unset, None, float] = UNSET,
    cvss3: Union[Unset, None, str] = UNSET,
    cvss3_score: Union[Unset, None, float] = UNSET,
    cwe_id: Union[Unset, None, str] = UNSET,
    description: Union[Unset, None, str] = UNSET,
    embargoed: Union[Unset, None, bool] = UNSET,
    exclude_fields: Union[Unset, None, List[str]] = UNSET,
    flaw_meta_type: Union[Unset, None, List[str]] = UNSET,
    format_: Union[Unset, None, FlawdbApiV1FlawsListFormat] = UNSET,
    impact: Union[Unset, None, FlawdbApiV1FlawsListImpact] = UNSET,
    include_fields: Union[Unset, None, List[str]] = UNSET,
    include_meta_attr: Union[Unset, None, List[str]] = UNSET,
    limit: Union[Unset, None, int] = UNSET,
    mitigated_by: Union[Unset, None, FlawdbApiV1FlawsListMitigatedBy] = UNSET,
    offset: Union[Unset, None, int] = UNSET,
    reported_dt: Union[Unset, None, datetime.datetime] = UNSET,
    resolution: Union[Unset, None, str] = UNSET,
    search: Union[Unset, None, str] = UNSET,
    source: Union[Unset, None, FlawdbApiV1FlawsListSource] = UNSET,
    state: Union[Unset, None, FlawdbApiV1FlawsListState] = UNSET,
    statement: Union[Unset, None, str] = UNSET,
    summary: Union[Unset, None, str] = UNSET,
    title: Union[Unset, None, str] = UNSET,
    tracker_ids: Union[Unset, None, List[str]] = UNSET,
    type: Union[Unset, None, FlawdbApiV1FlawsListType] = UNSET,
    unembargo_dt: Union[Unset, None, datetime.datetime] = UNSET,
    updated_dt: Union[Unset, None, datetime.datetime] = UNSET,
    uuid: Union[Unset, None, str] = UNSET,
) -> Response[PaginatedFlawList]:
    kwargs = _get_kwargs(
        client=client,
        bz_id=bz_id,
        changed_after=changed_after,
        changed_before=changed_before,
        created_dt=created_dt,
        cve_id=cve_id,
        cvss2=cvss2,
        cvss2_score=cvss2_score,
        cvss3=cvss3,
        cvss3_score=cvss3_score,
        cwe_id=cwe_id,
        description=description,
        embargoed=embargoed,
        exclude_fields=exclude_fields,
        flaw_meta_type=flaw_meta_type,
        format_=format_,
        impact=impact,
        include_fields=include_fields,
        include_meta_attr=include_meta_attr,
        limit=limit,
        mitigated_by=mitigated_by,
        offset=offset,
        reported_dt=reported_dt,
        resolution=resolution,
        search=search,
        source=source,
        state=state,
        statement=statement,
        summary=summary,
        title=title,
        tracker_ids=tracker_ids,
        type=type,
        unembargo_dt=unembargo_dt,
        updated_dt=updated_dt,
        uuid=uuid,
    )

    response = client.get_session().get(
        **kwargs,
    )
    response.raise_for_status()

    return _build_response(response=response)


def sync(
    *,
    client: AuthenticatedClient,
    bz_id: Union[Unset, None, float] = UNSET,
    changed_after: Union[Unset, None, datetime.datetime] = UNSET,
    changed_before: Union[Unset, None, datetime.datetime] = UNSET,
    created_dt: Union[Unset, None, datetime.datetime] = UNSET,
    cve_id: Union[Unset, None, List[str]] = UNSET,
    cvss2: Union[Unset, None, str] = UNSET,
    cvss2_score: Union[Unset, None, float] = UNSET,
    cvss3: Union[Unset, None, str] = UNSET,
    cvss3_score: Union[Unset, None, float] = UNSET,
    cwe_id: Union[Unset, None, str] = UNSET,
    description: Union[Unset, None, str] = UNSET,
    embargoed: Union[Unset, None, bool] = UNSET,
    exclude_fields: Union[Unset, None, List[str]] = UNSET,
    flaw_meta_type: Union[Unset, None, List[str]] = UNSET,
    format_: Union[Unset, None, FlawdbApiV1FlawsListFormat] = UNSET,
    impact: Union[Unset, None, FlawdbApiV1FlawsListImpact] = UNSET,
    include_fields: Union[Unset, None, List[str]] = UNSET,
    include_meta_attr: Union[Unset, None, List[str]] = UNSET,
    limit: Union[Unset, None, int] = UNSET,
    mitigated_by: Union[Unset, None, FlawdbApiV1FlawsListMitigatedBy] = UNSET,
    offset: Union[Unset, None, int] = UNSET,
    reported_dt: Union[Unset, None, datetime.datetime] = UNSET,
    resolution: Union[Unset, None, str] = UNSET,
    search: Union[Unset, None, str] = UNSET,
    source: Union[Unset, None, FlawdbApiV1FlawsListSource] = UNSET,
    state: Union[Unset, None, FlawdbApiV1FlawsListState] = UNSET,
    statement: Union[Unset, None, str] = UNSET,
    summary: Union[Unset, None, str] = UNSET,
    title: Union[Unset, None, str] = UNSET,
    tracker_ids: Union[Unset, None, List[str]] = UNSET,
    type: Union[Unset, None, FlawdbApiV1FlawsListType] = UNSET,
    unembargo_dt: Union[Unset, None, datetime.datetime] = UNSET,
    updated_dt: Union[Unset, None, datetime.datetime] = UNSET,
    uuid: Union[Unset, None, str] = UNSET,
) -> Optional[PaginatedFlawList]:
    """ """

    return sync_detailed(
        client=client,
        bz_id=bz_id,
        changed_after=changed_after,
        changed_before=changed_before,
        created_dt=created_dt,
        cve_id=cve_id,
        cvss2=cvss2,
        cvss2_score=cvss2_score,
        cvss3=cvss3,
        cvss3_score=cvss3_score,
        cwe_id=cwe_id,
        description=description,
        embargoed=embargoed,
        exclude_fields=exclude_fields,
        flaw_meta_type=flaw_meta_type,
        format_=format_,
        impact=impact,
        include_fields=include_fields,
        include_meta_attr=include_meta_attr,
        limit=limit,
        mitigated_by=mitigated_by,
        offset=offset,
        reported_dt=reported_dt,
        resolution=resolution,
        search=search,
        source=source,
        state=state,
        statement=statement,
        summary=summary,
        title=title,
        tracker_ids=tracker_ids,
        type=type,
        unembargo_dt=unembargo_dt,
        updated_dt=updated_dt,
        uuid=uuid,
    ).parsed


async def asyncio_detailed(
    *,
    client: AuthenticatedClient,
    bz_id: Union[Unset, None, float] = UNSET,
    changed_after: Union[Unset, None, datetime.datetime] = UNSET,
    changed_before: Union[Unset, None, datetime.datetime] = UNSET,
    created_dt: Union[Unset, None, datetime.datetime] = UNSET,
    cve_id: Union[Unset, None, List[str]] = UNSET,
    cvss2: Union[Unset, None, str] = UNSET,
    cvss2_score: Union[Unset, None, float] = UNSET,
    cvss3: Union[Unset, None, str] = UNSET,
    cvss3_score: Union[Unset, None, float] = UNSET,
    cwe_id: Union[Unset, None, str] = UNSET,
    description: Union[Unset, None, str] = UNSET,
    embargoed: Union[Unset, None, bool] = UNSET,
    exclude_fields: Union[Unset, None, List[str]] = UNSET,
    flaw_meta_type: Union[Unset, None, List[str]] = UNSET,
    format_: Union[Unset, None, FlawdbApiV1FlawsListFormat] = UNSET,
    impact: Union[Unset, None, FlawdbApiV1FlawsListImpact] = UNSET,
    include_fields: Union[Unset, None, List[str]] = UNSET,
    include_meta_attr: Union[Unset, None, List[str]] = UNSET,
    limit: Union[Unset, None, int] = UNSET,
    mitigated_by: Union[Unset, None, FlawdbApiV1FlawsListMitigatedBy] = UNSET,
    offset: Union[Unset, None, int] = UNSET,
    reported_dt: Union[Unset, None, datetime.datetime] = UNSET,
    resolution: Union[Unset, None, str] = UNSET,
    search: Union[Unset, None, str] = UNSET,
    source: Union[Unset, None, FlawdbApiV1FlawsListSource] = UNSET,
    state: Union[Unset, None, FlawdbApiV1FlawsListState] = UNSET,
    statement: Union[Unset, None, str] = UNSET,
    summary: Union[Unset, None, str] = UNSET,
    title: Union[Unset, None, str] = UNSET,
    tracker_ids: Union[Unset, None, List[str]] = UNSET,
    type: Union[Unset, None, FlawdbApiV1FlawsListType] = UNSET,
    unembargo_dt: Union[Unset, None, datetime.datetime] = UNSET,
    updated_dt: Union[Unset, None, datetime.datetime] = UNSET,
    uuid: Union[Unset, None, str] = UNSET,
) -> Response[PaginatedFlawList]:
    kwargs = _get_kwargs(
        client=client,
        bz_id=bz_id,
        changed_after=changed_after,
        changed_before=changed_before,
        created_dt=created_dt,
        cve_id=cve_id,
        cvss2=cvss2,
        cvss2_score=cvss2_score,
        cvss3=cvss3,
        cvss3_score=cvss3_score,
        cwe_id=cwe_id,
        description=description,
        embargoed=embargoed,
        exclude_fields=exclude_fields,
        flaw_meta_type=flaw_meta_type,
        format_=format_,
        impact=impact,
        include_fields=include_fields,
        include_meta_attr=include_meta_attr,
        limit=limit,
        mitigated_by=mitigated_by,
        offset=offset,
        reported_dt=reported_dt,
        resolution=resolution,
        search=search,
        source=source,
        state=state,
        statement=statement,
        summary=summary,
        title=title,
        tracker_ids=tracker_ids,
        type=type,
        unembargo_dt=unembargo_dt,
        updated_dt=updated_dt,
        uuid=uuid,
    )

    async with httpx.AsyncClient(verify=client.verify_ssl) as _client:
        response = await _client.get(**kwargs)

    return _build_response(response=response)


async def asyncio(
    *,
    client: AuthenticatedClient,
    bz_id: Union[Unset, None, float] = UNSET,
    changed_after: Union[Unset, None, datetime.datetime] = UNSET,
    changed_before: Union[Unset, None, datetime.datetime] = UNSET,
    created_dt: Union[Unset, None, datetime.datetime] = UNSET,
    cve_id: Union[Unset, None, List[str]] = UNSET,
    cvss2: Union[Unset, None, str] = UNSET,
    cvss2_score: Union[Unset, None, float] = UNSET,
    cvss3: Union[Unset, None, str] = UNSET,
    cvss3_score: Union[Unset, None, float] = UNSET,
    cwe_id: Union[Unset, None, str] = UNSET,
    description: Union[Unset, None, str] = UNSET,
    embargoed: Union[Unset, None, bool] = UNSET,
    exclude_fields: Union[Unset, None, List[str]] = UNSET,
    flaw_meta_type: Union[Unset, None, List[str]] = UNSET,
    format_: Union[Unset, None, FlawdbApiV1FlawsListFormat] = UNSET,
    impact: Union[Unset, None, FlawdbApiV1FlawsListImpact] = UNSET,
    include_fields: Union[Unset, None, List[str]] = UNSET,
    include_meta_attr: Union[Unset, None, List[str]] = UNSET,
    limit: Union[Unset, None, int] = UNSET,
    mitigated_by: Union[Unset, None, FlawdbApiV1FlawsListMitigatedBy] = UNSET,
    offset: Union[Unset, None, int] = UNSET,
    reported_dt: Union[Unset, None, datetime.datetime] = UNSET,
    resolution: Union[Unset, None, str] = UNSET,
    search: Union[Unset, None, str] = UNSET,
    source: Union[Unset, None, FlawdbApiV1FlawsListSource] = UNSET,
    state: Union[Unset, None, FlawdbApiV1FlawsListState] = UNSET,
    statement: Union[Unset, None, str] = UNSET,
    summary: Union[Unset, None, str] = UNSET,
    title: Union[Unset, None, str] = UNSET,
    tracker_ids: Union[Unset, None, List[str]] = UNSET,
    type: Union[Unset, None, FlawdbApiV1FlawsListType] = UNSET,
    unembargo_dt: Union[Unset, None, datetime.datetime] = UNSET,
    updated_dt: Union[Unset, None, datetime.datetime] = UNSET,
    uuid: Union[Unset, None, str] = UNSET,
) -> Optional[PaginatedFlawList]:
    """ """

    return (
        await asyncio_detailed(
            client=client,
            bz_id=bz_id,
            changed_after=changed_after,
            changed_before=changed_before,
            created_dt=created_dt,
            cve_id=cve_id,
            cvss2=cvss2,
            cvss2_score=cvss2_score,
            cvss3=cvss3,
            cvss3_score=cvss3_score,
            cwe_id=cwe_id,
            description=description,
            embargoed=embargoed,
            exclude_fields=exclude_fields,
            flaw_meta_type=flaw_meta_type,
            format_=format_,
            impact=impact,
            include_fields=include_fields,
            include_meta_attr=include_meta_attr,
            limit=limit,
            mitigated_by=mitigated_by,
            offset=offset,
            reported_dt=reported_dt,
            resolution=resolution,
            search=search,
            source=source,
            state=state,
            statement=statement,
            summary=summary,
            title=title,
            tracker_ids=tracker_ids,
            type=type,
            unembargo_dt=unembargo_dt,
            updated_dt=updated_dt,
            uuid=uuid,
        )
    ).parsed



import datetime
import json
from typing import Any, Dict, List, Tuple, Type, TypeVar, Union, cast

import attr
from dateutil.parser import isoparse

from ..models.state_enum import StateEnum
from ..types import UNSET, Unset

T = TypeVar("T", bound="Job")


@attr.s(auto_attribs=True)
class Job:
    """serialize job json"""

    uuid: str
    bz_count: str
    cve_count: str
    state: Union[None, StateEnum, Unset] = UNSET
    comment: Union[Unset, None, str] = UNSET
    created_dt: Union[Unset, None, datetime.datetime] = UNSET
    bz_ids: Union[Unset, List[str]] = UNSET
    dry_run: Union[Unset, bool] = UNSET
    update: Union[Unset, bool] = UNSET
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        uuid = self.uuid
        bz_count = self.bz_count
        cve_count = self.cve_count
        state: Union[None, Unset, str]
        if isinstance(self.state, Unset):
            state = UNSET
        elif self.state is None:
            state = None
        elif isinstance(self.state, StateEnum):
            state = UNSET
            if not isinstance(self.state, Unset):

                state = StateEnum(self.state).value

        else:
            state = self.state

        comment = self.comment
        created_dt: Union[Unset, None, str] = UNSET
        if not isinstance(self.created_dt, Unset):
            created_dt = self.created_dt.isoformat() if self.created_dt else None

        bz_ids: Union[Unset, List[str]] = UNSET
        if not isinstance(self.bz_ids, Unset):
            bz_ids = self.bz_ids

        dry_run = self.dry_run
        update = self.update

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        if uuid is not UNSET:
            field_dict["uuid"] = uuid
        if bz_count is not UNSET:
            field_dict["bz_count"] = bz_count
        if cve_count is not UNSET:
            field_dict["cve_count"] = cve_count
        if state is not UNSET:
            field_dict["state"] = state
        if comment is not UNSET:
            field_dict["comment"] = comment
        if created_dt is not UNSET:
            field_dict["created_dt"] = created_dt
        if bz_ids is not UNSET:
            field_dict["bz_ids"] = bz_ids
        if dry_run is not UNSET:
            field_dict["dry_run"] = dry_run
        if update is not UNSET:
            field_dict["update"] = update

        return field_dict

    def to_multipart(self) -> Dict[str, Any]:
        uuid = self.uuid if self.uuid is UNSET else (None, str(self.uuid), "text/plain")
        bz_count = self.bz_count if self.bz_count is UNSET else (None, str(self.bz_count), "text/plain")
        cve_count = self.cve_count if self.cve_count is UNSET else (None, str(self.cve_count), "text/plain")
        state: Union[None, Unset, str]
        if isinstance(self.state, Unset):
            state = UNSET
        elif self.state is None:
            state = None
        elif isinstance(self.state, StateEnum):
            state = UNSET
            if not isinstance(self.state, Unset):

                state = StateEnum(self.state).value

        else:
            state = self.state

        comment = self.comment if self.comment is UNSET else (None, str(self.comment), "text/plain")
        created_dt: Union[Unset, None, str] = UNSET
        if not isinstance(self.created_dt, Unset):
            created_dt = self.created_dt.isoformat() if self.created_dt else None

        bz_ids: Union[Unset, Tuple[None, str, str]] = UNSET
        if not isinstance(self.bz_ids, Unset):
            _temp_bz_ids = self.bz_ids
            bz_ids = (None, json.dumps(_temp_bz_ids), "application/json")

        dry_run = self.dry_run if self.dry_run is UNSET else (None, str(self.dry_run), "text/plain")
        update = self.update if self.update is UNSET else (None, str(self.update), "text/plain")

        field_dict: Dict[str, Any] = {}
        field_dict.update({key: (None, str(value), "text/plain") for key, value in self.additional_properties.items()})
        if uuid is not UNSET:
            field_dict["uuid"] = uuid
        if bz_count is not UNSET:
            field_dict["bz_count"] = bz_count
        if cve_count is not UNSET:
            field_dict["cve_count"] = cve_count
        if state is not UNSET:
            field_dict["state"] = state
        if comment is not UNSET:
            field_dict["comment"] = comment
        if created_dt is not UNSET:
            field_dict["created_dt"] = created_dt
        if bz_ids is not UNSET:
            field_dict["bz_ids"] = bz_ids
        if dry_run is not UNSET:
            field_dict["dry_run"] = dry_run
        if update is not UNSET:
            field_dict["update"] = update

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        uuid = d.pop("uuid", UNSET)

        bz_count = d.pop("bz_count", UNSET)

        cve_count = d.pop("cve_count", UNSET)

        def _parse_state(data: object) -> Union[None, StateEnum, Unset]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, str):
                    raise TypeError()
                _state_type_0 = data
                state_type_0: Union[Unset, StateEnum]
                if isinstance(_state_type_0, Unset):
                    state_type_0 = UNSET
                else:
                    state_type_0 = StateEnum(_state_type_0)

                return state_type_0
            except:  # noqa: E722
                pass
            return cast(Union[None, StateEnum, Unset], data)

        state = _parse_state(d.pop("state", UNSET))

        comment = d.pop("comment", UNSET)

        _created_dt = d.pop("created_dt", UNSET)
        created_dt: Union[Unset, None, datetime.datetime]
        if _created_dt is None:
            created_dt = None
        elif isinstance(_created_dt, Unset):
            created_dt = UNSET
        else:
            created_dt = isoparse(_created_dt)

        bz_ids = cast(List[str], d.pop("bz_ids", UNSET))

        dry_run = d.pop("dry_run", UNSET)

        update = d.pop("update", UNSET)

        job = cls(
            uuid=uuid,
            bz_count=bz_count,
            cve_count=cve_count,
            state=state,
            comment=comment,
            created_dt=created_dt,
            bz_ids=bz_ids,
            dry_run=dry_run,
            update=update,
        )

        job.additional_properties = d
        return job

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import Any, Dict, Optional, Union

import httpx

from ...client import AuthenticatedClient
from ...models.flawdb_api_v1_schema_retrieve_format import FlawdbApiV1SchemaRetrieveFormat
from ...models.flawdb_api_v1_schema_retrieve_lang import FlawdbApiV1SchemaRetrieveLang
from ...models.flawdb_api_v1_schema_retrieve_response_200 import FlawdbApiV1SchemaRetrieveResponse200
from ...types import UNSET, Response, Unset


def _get_kwargs(
    *,
    client: AuthenticatedClient,
    format_: Union[Unset, None, FlawdbApiV1SchemaRetrieveFormat] = UNSET,
    lang: Union[Unset, None, FlawdbApiV1SchemaRetrieveLang] = UNSET,
) -> Dict[str, Any]:
    url = "/flawdb/api/v1/schema/"

    json_format_: Union[Unset, None, str] = UNSET
    if not isinstance(format_, Unset):

        json_format_ = FlawdbApiV1SchemaRetrieveFormat(format_).value if format_ else None

    json_lang: Union[Unset, None, str] = UNSET
    if not isinstance(lang, Unset):

        json_lang = FlawdbApiV1SchemaRetrieveLang(lang).value if lang else None

    params: Dict[str, Any] = {
        "format": json_format_,
        "lang": json_lang,
    }
    params = {k: v for k, v in params.items() if v is not UNSET and v is not None}

    return {
        "url": url,
        "params": params,
    }


def _parse_response(*, response: httpx.Response) -> Optional[FlawdbApiV1SchemaRetrieveResponse200]:
    if response.status_code == 200:
        _response_200 = response.json()
        response_200: FlawdbApiV1SchemaRetrieveResponse200
        if isinstance(_response_200, Unset):
            response_200 = UNSET
        else:
            response_200 = FlawdbApiV1SchemaRetrieveResponse200.from_dict(_response_200)

        return response_200
    return None


def _build_response(*, response: httpx.Response) -> Response[FlawdbApiV1SchemaRetrieveResponse200]:
    return Response(
        status_code=response.status_code,
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(response=response),
    )


def sync_detailed(
    *,
    client: AuthenticatedClient,
    format_: Union[Unset, None, FlawdbApiV1SchemaRetrieveFormat] = UNSET,
    lang: Union[Unset, None, FlawdbApiV1SchemaRetrieveLang] = UNSET,
) -> Response[FlawdbApiV1SchemaRetrieveResponse200]:
    kwargs = _get_kwargs(
        client=client,
        format_=format_,
        lang=lang,
    )

    response = client.get_session().get(
        **kwargs,
    )
    response.raise_for_status()

    return _build_response(response=response)


def sync(
    *,
    client: AuthenticatedClient,
    format_: Union[Unset, None, FlawdbApiV1SchemaRetrieveFormat] = UNSET,
    lang: Union[Unset, None, FlawdbApiV1SchemaRetrieveLang] = UNSET,
) -> Optional[FlawdbApiV1SchemaRetrieveResponse200]:
    """OpenApi3 schema for this API. Format can be selected via content negotiation.

    - YAML: application/vnd.oai.openapi
    - JSON: application/vnd.oai.openapi+json"""

    return sync_detailed(
        client=client,
        format_=format_,
        lang=lang,
    ).parsed


async def asyncio_detailed(
    *,
    client: AuthenticatedClient,
    format_: Union[Unset, None, FlawdbApiV1SchemaRetrieveFormat] = UNSET,
    lang: Union[Unset, None, FlawdbApiV1SchemaRetrieveLang] = UNSET,
) -> Response[FlawdbApiV1SchemaRetrieveResponse200]:
    kwargs = _get_kwargs(
        client=client,
        format_=format_,
        lang=lang,
    )

    async with httpx.AsyncClient(verify=client.verify_ssl) as _client:
        response = await _client.get(**kwargs)

    return _build_response(response=response)


async def asyncio(
    *,
    client: AuthenticatedClient,
    format_: Union[Unset, None, FlawdbApiV1SchemaRetrieveFormat] = UNSET,
    lang: Union[Unset, None, FlawdbApiV1SchemaRetrieveLang] = UNSET,
) -> Optional[FlawdbApiV1SchemaRetrieveResponse200]:
    """OpenApi3 schema for this API. Format can be selected via content negotiation.

    - YAML: application/vnd.oai.openapi
    - JSON: application/vnd.oai.openapi+json"""

    return (
        await asyncio_detailed(
            client=client,
            format_=format_,
            lang=lang,
        )
    ).parsed



import datetime
from typing import Any, Dict, List, Type, TypeVar, Union

import attr
from dateutil.parser import isoparse

from ..models.flawdb_api_v1_status_retrieve_response_200_flawdb_data import (
    FlawdbApiV1StatusRetrieveResponse200FlawdbData,
)
from ..models.flawdb_api_v1_status_retrieve_response_200_flawdb_service import (
    FlawdbApiV1StatusRetrieveResponse200FlawdbService,
)
from ..types import UNSET, Unset

T = TypeVar("T", bound="FlawdbApiV1StatusRetrieveResponse200")


@attr.s(auto_attribs=True)
class FlawdbApiV1StatusRetrieveResponse200:
    """ """

    status: Union[Unset, str] = UNSET
    dt: Union[Unset, datetime.datetime] = UNSET
    flawdb_service: Union[Unset, FlawdbApiV1StatusRetrieveResponse200FlawdbService] = UNSET
    flawdb_data: Union[Unset, FlawdbApiV1StatusRetrieveResponse200FlawdbData] = UNSET
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        status = self.status
        dt: Union[Unset, str] = UNSET
        if not isinstance(self.dt, Unset):
            dt = self.dt.isoformat()

        flawdb_service: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.flawdb_service, Unset):
            flawdb_service = self.flawdb_service.to_dict()

        flawdb_data: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.flawdb_data, Unset):
            flawdb_data = self.flawdb_data.to_dict()

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        if status is not UNSET:
            field_dict["status"] = status
        if dt is not UNSET:
            field_dict["dt"] = dt
        if flawdb_service is not UNSET:
            field_dict["flawdb_service"] = flawdb_service
        if flawdb_data is not UNSET:
            field_dict["flawdb_data"] = flawdb_data

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        status = d.pop("status", UNSET)

        _dt = d.pop("dt", UNSET)
        dt: Union[Unset, datetime.datetime]
        if isinstance(_dt, Unset):
            dt = UNSET
        else:
            dt = isoparse(_dt)

        _flawdb_service = d.pop("flawdb_service", UNSET)
        flawdb_service: Union[Unset, FlawdbApiV1StatusRetrieveResponse200FlawdbService]
        if isinstance(_flawdb_service, Unset):
            flawdb_service = UNSET
        else:
            flawdb_service = FlawdbApiV1StatusRetrieveResponse200FlawdbService.from_dict(_flawdb_service)

        _flawdb_data = d.pop("flawdb_data", UNSET)
        flawdb_data: Union[Unset, FlawdbApiV1StatusRetrieveResponse200FlawdbData]
        if isinstance(_flawdb_data, Unset):
            flawdb_data = UNSET
        else:
            flawdb_data = FlawdbApiV1StatusRetrieveResponse200FlawdbData.from_dict(_flawdb_data)

        flawdb_api_v1_status_retrieve_response_200 = cls(
            status=status,
            dt=dt,
            flawdb_service=flawdb_service,
            flawdb_data=flawdb_data,
        )

        flawdb_api_v1_status_retrieve_response_200.additional_properties = d
        return flawdb_api_v1_status_retrieve_response_200

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import Any, Dict, Optional, Union

import httpx

from ...client import AuthenticatedClient
from ...models.jiraffe_api_v1_jobs_list_format import JiraffeApiV1JobsListFormat
from ...models.paginated_jiraffe_job_list import PaginatedJiraffeJobList
from ...types import UNSET, Response, Unset


def _get_kwargs(
    *,
    client: AuthenticatedClient,
    format_: Union[Unset, None, JiraffeApiV1JobsListFormat] = UNSET,
    limit: Union[Unset, None, int] = UNSET,
    offset: Union[Unset, None, int] = UNSET,
) -> Dict[str, Any]:
    url = "/jiraffe/api/v1/jobs"

    json_format_: Union[Unset, None, str] = UNSET
    if not isinstance(format_, Unset):

        json_format_ = JiraffeApiV1JobsListFormat(format_).value if format_ else None

    params: Dict[str, Any] = {
        "format": json_format_,
        "limit": limit,
        "offset": offset,
    }
    params = {k: v for k, v in params.items() if v is not UNSET and v is not None}

    return {
        "url": url,
        "params": params,
    }


def _parse_response(*, response: httpx.Response) -> Optional[PaginatedJiraffeJobList]:
    if response.status_code == 200:
        _response_200 = response.json()
        response_200: PaginatedJiraffeJobList
        if isinstance(_response_200, Unset):
            response_200 = UNSET
        else:
            response_200 = PaginatedJiraffeJobList.from_dict(_response_200)

        return response_200
    return None


def _build_response(*, response: httpx.Response) -> Response[PaginatedJiraffeJobList]:
    return Response(
        status_code=response.status_code,
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(response=response),
    )


def sync_detailed(
    *,
    client: AuthenticatedClient,
    format_: Union[Unset, None, JiraffeApiV1JobsListFormat] = UNSET,
    limit: Union[Unset, None, int] = UNSET,
    offset: Union[Unset, None, int] = UNSET,
) -> Response[PaginatedJiraffeJobList]:
    kwargs = _get_kwargs(
        client=client,
        format_=format_,
        limit=limit,
        offset=offset,
    )

    response = client.get_session().get(
        **kwargs,
    )
    response.raise_for_status()

    return _build_response(response=response)


def sync(
    *,
    client: AuthenticatedClient,
    format_: Union[Unset, None, JiraffeApiV1JobsListFormat] = UNSET,
    limit: Union[Unset, None, int] = UNSET,
    offset: Union[Unset, None, int] = UNSET,
) -> Optional[PaginatedJiraffeJobList]:
    """Fetch list of JiraffeJobs"""

    return sync_detailed(
        client=client,
        format_=format_,
        limit=limit,
        offset=offset,
    ).parsed


async def asyncio_detailed(
    *,
    client: AuthenticatedClient,
    format_: Union[Unset, None, JiraffeApiV1JobsListFormat] = UNSET,
    limit: Union[Unset, None, int] = UNSET,
    offset: Union[Unset, None, int] = UNSET,
) -> Response[PaginatedJiraffeJobList]:
    kwargs = _get_kwargs(
        client=client,
        format_=format_,
        limit=limit,
        offset=offset,
    )

    async with httpx.AsyncClient(verify=client.verify_ssl) as _client:
        response = await _client.get(**kwargs)

    return _build_response(response=response)


async def asyncio(
    *,
    client: AuthenticatedClient,
    format_: Union[Unset, None, JiraffeApiV1JobsListFormat] = UNSET,
    limit: Union[Unset, None, int] = UNSET,
    offset: Union[Unset, None, int] = UNSET,
) -> Optional[PaginatedJiraffeJobList]:
    """Fetch list of JiraffeJobs"""

    return (
        await asyncio_detailed(
            client=client,
            format_=format_,
            limit=limit,
            offset=offset,
        )
    ).parsed



from typing import Any, Dict, Optional, Union

import httpx

from ...client import AuthenticatedClient
from ...models.flaw import Flaw
from ...models.flawdb_api_v1_flaws_update_format import FlawdbApiV1FlawsUpdateFormat
from ...types import UNSET, Response, Unset


def _get_kwargs(
    id: str,
    *,
    client: AuthenticatedClient,
    form_data: Flaw,
    multipart_data: Flaw,
    json_body: Flaw,
    format_: Union[Unset, None, FlawdbApiV1FlawsUpdateFormat] = UNSET,
) -> Dict[str, Any]:
    url = "/flawdb/api/v1/flaws/{id}".format(
        id=id,
    )

    json_format_: Union[Unset, None, str] = UNSET
    if not isinstance(format_, Unset):

        json_format_ = FlawdbApiV1FlawsUpdateFormat(format_).value if format_ else None

    params: Dict[str, Any] = {
        "format": json_format_,
    }
    params = {k: v for k, v in params.items() if v is not UNSET and v is not None}

    json_json_body: Dict[str, Any] = UNSET
    if not isinstance(json_body, Unset):
        json_body.to_dict()

    multipart_multipart_data: Dict[str, Any] = UNSET
    if not isinstance(multipart_data, Unset):
        multipart_data.to_multipart()

    return {
        "url": url,
        "data": form_data.to_dict(),
        "params": params,
    }


def _parse_response(*, response: httpx.Response) -> Optional[Flaw]:
    if response.status_code == 200:
        _response_200 = response.json()
        response_200: Flaw
        if isinstance(_response_200, Unset):
            response_200 = UNSET
        else:
            response_200 = Flaw.from_dict(_response_200)

        return response_200
    return None


def _build_response(*, response: httpx.Response) -> Response[Flaw]:
    return Response(
        status_code=response.status_code,
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(response=response),
    )


def sync_detailed(
    id: str,
    *,
    client: AuthenticatedClient,
    form_data: Flaw,
    multipart_data: Flaw,
    json_body: Flaw,
    format_: Union[Unset, None, FlawdbApiV1FlawsUpdateFormat] = UNSET,
) -> Response[Flaw]:
    kwargs = _get_kwargs(
        id=id,
        client=client,
        form_data=form_data,
        multipart_data=multipart_data,
        json_body=json_body,
        format_=format_,
    )

    response = client.get_session().put(
        **kwargs,
    )
    response.raise_for_status()

    return _build_response(response=response)


def sync(
    id: str,
    *,
    client: AuthenticatedClient,
    form_data: Flaw,
    multipart_data: Flaw,
    json_body: Flaw,
    format_: Union[Unset, None, FlawdbApiV1FlawsUpdateFormat] = UNSET,
) -> Optional[Flaw]:
    """ """

    return sync_detailed(
        id=id,
        client=client,
        form_data=form_data,
        multipart_data=multipart_data,
        json_body=json_body,
        format_=format_,
    ).parsed


async def asyncio_detailed(
    id: str,
    *,
    client: AuthenticatedClient,
    form_data: Flaw,
    multipart_data: Flaw,
    json_body: Flaw,
    format_: Union[Unset, None, FlawdbApiV1FlawsUpdateFormat] = UNSET,
) -> Response[Flaw]:
    kwargs = _get_kwargs(
        id=id,
        client=client,
        form_data=form_data,
        multipart_data=multipart_data,
        json_body=json_body,
        format_=format_,
    )

    async with httpx.AsyncClient(verify=client.verify_ssl) as _client:
        response = await _client.put(**kwargs)

    return _build_response(response=response)


async def asyncio(
    id: str,
    *,
    client: AuthenticatedClient,
    form_data: Flaw,
    multipart_data: Flaw,
    json_body: Flaw,
    format_: Union[Unset, None, FlawdbApiV1FlawsUpdateFormat] = UNSET,
) -> Optional[Flaw]:
    """ """

    return (
        await asyncio_detailed(
            id=id,
            client=client,
            form_data=form_data,
            multipart_data=multipart_data,
            json_body=json_body,
            format_=format_,
        )
    ).parsed



""" Contains all the data models used in inputs/outputs """

from .affect import Affect
from .affect_type_enum import AffectTypeEnum
from .affectedness_enum import AffectednessEnum
from .auth_token import AuthToken
from .blank_enum import BlankEnum
from .bzimport_api_v1_jobs_create_format import BzimportApiV1JobsCreateFormat
from .bzimport_api_v1_jobs_destroy_format import BzimportApiV1JobsDestroyFormat
from .bzimport_api_v1_jobs_list_format import BzimportApiV1JobsListFormat
from .bzimport_api_v1_jobs_retrieve_format import BzimportApiV1JobsRetrieveFormat
from .bzimport_api_v1_status_retrieve_format import BzimportApiV1StatusRetrieveFormat
from .bzimport_api_v1_sync_create_format import BzimportApiV1SyncCreateFormat
from .bzimport_healthy_retrieve_format import BzimportHealthyRetrieveFormat
from .comment import Comment
from .comment_meta_attr import CommentMetaAttr
from .comment_type_enum import CommentTypeEnum
from .cv_ev_5_package_versions import CVEv5PackageVersions
from .cv_ev_5_versions import CVEv5Versions
from .flaw import Flaw
from .flaw_classification import FlawClassification
from .flaw_classification_state import FlawClassificationState
from .flaw_meta_attr import FlawMetaAttr
from .flaw_type_enum import FlawTypeEnum
from .flawdb_api_v1_flaws_create_format import FlawdbApiV1FlawsCreateFormat
from .flawdb_api_v1_flaws_destroy_format import FlawdbApiV1FlawsDestroyFormat
from .flawdb_api_v1_flaws_list_format import FlawdbApiV1FlawsListFormat
from .flawdb_api_v1_flaws_list_impact import FlawdbApiV1FlawsListImpact
from .flawdb_api_v1_flaws_list_mitigated_by import FlawdbApiV1FlawsListMitigatedBy
from .flawdb_api_v1_flaws_list_source import FlawdbApiV1FlawsListSource
from .flawdb_api_v1_flaws_list_state import FlawdbApiV1FlawsListState
from .flawdb_api_v1_flaws_list_type import FlawdbApiV1FlawsListType
from .flawdb_api_v1_flaws_retrieve_format import FlawdbApiV1FlawsRetrieveFormat
from .flawdb_api_v1_flaws_update_format import FlawdbApiV1FlawsUpdateFormat
from .flawdb_api_v1_manifest_retrieve_format import FlawdbApiV1ManifestRetrieveFormat
from .flawdb_api_v1_schema_retrieve_format import FlawdbApiV1SchemaRetrieveFormat
from .flawdb_api_v1_schema_retrieve_lang import FlawdbApiV1SchemaRetrieveLang
from .flawdb_api_v1_schema_retrieve_response_200 import FlawdbApiV1SchemaRetrieveResponse200
from .flawdb_api_v1_status_retrieve_format import FlawdbApiV1StatusRetrieveFormat
from .flawdb_api_v1_status_retrieve_response_200 import FlawdbApiV1StatusRetrieveResponse200
from .flawdb_api_v1_status_retrieve_response_200_flawdb_data import FlawdbApiV1StatusRetrieveResponse200FlawdbData
from .flawdb_api_v1_status_retrieve_response_200_flawdb_service import FlawdbApiV1StatusRetrieveResponse200FlawdbService
from .flawdb_healthy_retrieve_format import FlawdbHealthyRetrieveFormat
from .impact_enum import ImpactEnum
from .jiraffe_api_v1_jobs_create_format import JiraffeApiV1JobsCreateFormat
from .jiraffe_api_v1_jobs_destroy_format import JiraffeApiV1JobsDestroyFormat
from .jiraffe_api_v1_jobs_list_format import JiraffeApiV1JobsListFormat
from .jiraffe_api_v1_jobs_retrieve_format import JiraffeApiV1JobsRetrieveFormat
from .jiraffe_api_v1_status_retrieve_format import JiraffeApiV1StatusRetrieveFormat
from .jiraffe_api_v1_sync_create_format import JiraffeApiV1SyncCreateFormat
from .jiraffe_healthy_retrieve_format import JiraffeHealthyRetrieveFormat
from .jiraffe_job import JiraffeJob
from .job import Job
from .meta import Meta
from .meta_meta_attr import MetaMetaAttr
from .meta_type_enum import MetaTypeEnum
from .mitigated_by_enum import MitigatedByEnum
from .osim_api_v1_workflows_adjust_create_format import OsimApiV1WorkflowsAdjustCreateFormat
from .osim_api_v1_workflows_retrieve_2_format import OsimApiV1WorkflowsRetrieve2Format
from .osim_api_v1_workflows_retrieve_format import OsimApiV1WorkflowsRetrieveFormat
from .osim_healthy_retrieve_format import OsimHealthyRetrieveFormat
from .osim_retrieve_format import OsimRetrieveFormat
from .paginated_flaw_list import PaginatedFlawList
from .paginated_jiraffe_job_list import PaginatedJiraffeJobList
from .paginated_job_list import PaginatedJobList
from .resolution_enum import ResolutionEnum
from .source_enum import SourceEnum
from .state_enum import StateEnum
from .status_enum import StatusEnum
from .tracker import Tracker
from .tracker_type_enum import TrackerTypeEnum



from enum import Enum


class FlawdbApiV1FlawsListState(str, Enum):
    ASSIGNED = "ASSIGNED"
    CLOSED = "CLOSED"
    DRAFT = "DRAFT"
    NEW = "NEW"
    OPEN = "OPEN"
    STUB = "STUB"
    VERIFIED = "VERIFIED"

    def __str__(self) -> str:
        return str(self.value)



from typing import Any, Dict, List, Type, TypeVar, Union, cast

import attr

from ..models.tracker_type_enum import TrackerTypeEnum
from ..types import UNSET, Unset

T = TypeVar("T", bound="Tracker")


@attr.s(auto_attribs=True)
class Tracker:
    """Tracker serializer"""

    uuid: str
    type: Union[None, TrackerTypeEnum, Unset] = UNSET
    external_system_id: Union[Unset, None, str] = UNSET
    status: Union[Unset, None, str] = UNSET
    resolution: Union[Unset, None, str] = UNSET
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        uuid = self.uuid
        type: Union[None, Unset, str]
        if isinstance(self.type, Unset):
            type = UNSET
        elif self.type is None:
            type = None
        elif isinstance(self.type, TrackerTypeEnum):
            type = UNSET
            if not isinstance(self.type, Unset):

                type = TrackerTypeEnum(self.type).value

        else:
            type = self.type

        external_system_id = self.external_system_id
        status = self.status
        resolution = self.resolution

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        if uuid is not UNSET:
            field_dict["uuid"] = uuid
        if type is not UNSET:
            field_dict["type"] = type
        if external_system_id is not UNSET:
            field_dict["external_system_id"] = external_system_id
        if status is not UNSET:
            field_dict["status"] = status
        if resolution is not UNSET:
            field_dict["resolution"] = resolution

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        uuid = d.pop("uuid", UNSET)

        def _parse_type(data: object) -> Union[None, TrackerTypeEnum, Unset]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, str):
                    raise TypeError()
                _type_type_0 = data
                type_type_0: Union[Unset, TrackerTypeEnum]
                if isinstance(_type_type_0, Unset):
                    type_type_0 = UNSET
                else:
                    type_type_0 = TrackerTypeEnum(_type_type_0)

                return type_type_0
            except:  # noqa: E722
                pass
            return cast(Union[None, TrackerTypeEnum, Unset], data)

        type = _parse_type(d.pop("type", UNSET))

        external_system_id = d.pop("external_system_id", UNSET)

        status = d.pop("status", UNSET)

        resolution = d.pop("resolution", UNSET)

        tracker = cls(
            uuid=uuid,
            type=type,
            external_system_id=external_system_id,
            status=status,
            resolution=resolution,
        )

        tracker.additional_properties = d
        return tracker

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



import importlib

from .constants import (
    OSIDB_API_VERSION,
    OSIDB_BINDINGS_API_PATH,
)
from .bindings.python_client import AuthenticatedClient

# TODO: Once FlawDB will be renamed to OSIDB, these paths need to be changed
osidb_flaws_list = importlib.import_module(
    f"{OSIDB_BINDINGS_API_PATH}.flawdb_api_{OSIDB_API_VERSION}_flaws_list",
    package="osidb_bindings",
)
osidb_flaws_retrieve = importlib.import_module(
    f"{OSIDB_BINDINGS_API_PATH}.flawdb_api_{OSIDB_API_VERSION}_flaws_retrieve",
    package="osidb_bindings",
)
osidb_status_retrieve = importlib.import_module(
    f"{OSIDB_BINDINGS_API_PATH}.flawdb_api_{OSIDB_API_VERSION}_status_retrieve",
    package="osidb_bindings",
)


def new_session(
    osidb_server_uri, password=None, username=None, token=None, verify_ssl=True
):
    """Create a new session for selected OSIDB URI"""

    auth = None
    headers = {}

    if username and password:
        auth = (username, password)
    elif token:
        headers["Authorization"] = f"Token {token}"
    else:
        raise NotImplementedError("Kerberos authentication not implemented yet.")

    return Session(
        base_url=osidb_server_uri, auth=auth, headers=headers, verify_ssl=verify_ssl
    )


class Session:
    """Simple session wrapper which encapsulates the client"""

    def __init__(self, base_url, auth=None, headers=None, verify_ssl=None):

        if not headers:
            headers = {}

        self.__client = AuthenticatedClient(
            base_url=base_url,
            auth=auth,
            headers=headers,
            verify_ssl=verify_ssl,
        )

    def status(self):
        return osidb_status_retrieve.sync(client=self.__client)

    def retrieve(self, **kwargs):
        return osidb_flaws_retrieve.sync(client=self.__client, **kwargs)

    def retrieve_list(self, **kwargs):
        return osidb_flaws_list.sync(client=self.__client, **kwargs)

    def search(self, searched_text):
        return osidb_flaws_list.sync(client=self.__client, search=searched_text)

    def create(self):
        raise NotImplementedError("Flaw create not implemented yet.")

    def update(self):
        raise NotImplementedError("Flaw update not implemented yet")

    def delete(self):
        raise NotImplementedError("Flaw delete not implemented yet.")

    def reload_session(self):
        self.__client.reload_session()



from typing import Any, Dict, Union

import httpx

from ...client import AuthenticatedClient
from ...models.jiraffe_api_v1_jobs_retrieve_format import JiraffeApiV1JobsRetrieveFormat
from ...types import UNSET, Response, Unset


def _get_kwargs(
    id: str,
    *,
    client: AuthenticatedClient,
    format_: Union[Unset, None, JiraffeApiV1JobsRetrieveFormat] = UNSET,
) -> Dict[str, Any]:
    url = "/jiraffe/api/v1/jobs/{id}".format(
        id=id,
    )

    json_format_: Union[Unset, None, str] = UNSET
    if not isinstance(format_, Unset):

        json_format_ = JiraffeApiV1JobsRetrieveFormat(format_).value if format_ else None

    params: Dict[str, Any] = {
        "format": json_format_,
    }
    params = {k: v for k, v in params.items() if v is not UNSET and v is not None}

    return {
        "url": url,
        "params": params,
    }


def _build_response(*, response: httpx.Response) -> Response[Any]:
    return Response(
        status_code=response.status_code,
        content=response.content,
        headers=response.headers,
        parsed=None,
    )


def sync_detailed(
    id: str,
    *,
    client: AuthenticatedClient,
    format_: Union[Unset, None, JiraffeApiV1JobsRetrieveFormat] = UNSET,
) -> Response[Any]:
    kwargs = _get_kwargs(
        id=id,
        client=client,
        format_=format_,
    )

    response = client.get_session().get(
        **kwargs,
    )
    response.raise_for_status()

    return _build_response(response=response)


async def asyncio_detailed(
    id: str,
    *,
    client: AuthenticatedClient,
    format_: Union[Unset, None, JiraffeApiV1JobsRetrieveFormat] = UNSET,
) -> Response[Any]:
    kwargs = _get_kwargs(
        id=id,
        client=client,
        format_=format_,
    )

    async with httpx.AsyncClient(verify=client.verify_ssl) as _client:
        response = await _client.get(**kwargs)

    return _build_response(response=response)



from enum import Enum


class ImpactEnum(str, Enum):
    NONE = "NONE"
    LOW = "LOW"
    MODERATE = "MODERATE"
    IMPORTANT = "IMPORTANT"
    CRITICAL = "CRITICAL"

    def __str__(self) -> str:
        return str(self.value)



from typing import Any, Dict, List, Type, TypeVar, Union, cast

import attr

from ..models.affect_type_enum import AffectTypeEnum
from ..models.affectedness_enum import AffectednessEnum
from ..models.blank_enum import BlankEnum
from ..models.impact_enum import ImpactEnum
from ..models.resolution_enum import ResolutionEnum
from ..models.tracker import Tracker
from ..types import UNSET, Unset

T = TypeVar("T", bound="Affect")


@attr.s(auto_attribs=True)
class Affect:
    """Affect serializer"""

    uuid: str
    trackers: List[Tracker]
    type: Union[AffectTypeEnum, None, Unset] = UNSET
    affectedness: Union[AffectednessEnum, None, Unset] = UNSET
    resolution: Union[None, ResolutionEnum, Unset] = UNSET
    ps_module: Union[Unset, None, str] = UNSET
    ps_component: Union[Unset, None, str] = UNSET
    statement: Union[Unset, None, str] = UNSET
    impact: Union[BlankEnum, ImpactEnum, None, Unset] = UNSET
    cvss2: Union[Unset, None, str] = UNSET
    cvss2_score: Union[Unset, None, float] = UNSET
    cvss3: Union[Unset, None, str] = UNSET
    cvss3_score: Union[Unset, None, float] = UNSET
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        uuid = self.uuid
        trackers: List[Dict[str, Any]] = UNSET
        if not isinstance(self.trackers, Unset):
            trackers = []
            for trackers_item_data in self.trackers:
                trackers_item: Dict[str, Any] = UNSET
                if not isinstance(trackers_item_data, Unset):
                    trackers_item = trackers_item_data.to_dict()

                trackers.append(trackers_item)

        type: Union[None, Unset, str]
        if isinstance(self.type, Unset):
            type = UNSET
        elif self.type is None:
            type = None
        elif isinstance(self.type, AffectTypeEnum):
            type = UNSET
            if not isinstance(self.type, Unset):

                type = AffectTypeEnum(self.type).value

        else:
            type = self.type

        affectedness: Union[None, Unset, str]
        if isinstance(self.affectedness, Unset):
            affectedness = UNSET
        elif self.affectedness is None:
            affectedness = None
        elif isinstance(self.affectedness, AffectednessEnum):
            affectedness = UNSET
            if not isinstance(self.affectedness, Unset):

                affectedness = AffectednessEnum(self.affectedness).value

        else:
            affectedness = self.affectedness

        resolution: Union[None, Unset, str]
        if isinstance(self.resolution, Unset):
            resolution = UNSET
        elif self.resolution is None:
            resolution = None
        elif isinstance(self.resolution, ResolutionEnum):
            resolution = UNSET
            if not isinstance(self.resolution, Unset):

                resolution = ResolutionEnum(self.resolution).value

        else:
            resolution = self.resolution

        ps_module = self.ps_module
        ps_component = self.ps_component
        statement = self.statement
        impact: Union[None, Unset, str]
        if isinstance(self.impact, Unset):
            impact = UNSET
        elif self.impact is None:
            impact = None
        elif isinstance(self.impact, ImpactEnum):
            impact = UNSET
            if not isinstance(self.impact, Unset):

                impact = ImpactEnum(self.impact).value

        elif isinstance(self.impact, BlankEnum):
            impact = UNSET
            if not isinstance(self.impact, Unset):

                impact = BlankEnum(self.impact).value

        else:
            impact = self.impact

        cvss2 = self.cvss2
        cvss2_score = self.cvss2_score
        cvss3 = self.cvss3
        cvss3_score = self.cvss3_score

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        if uuid is not UNSET:
            field_dict["uuid"] = uuid
        if trackers is not UNSET:
            field_dict["trackers"] = trackers
        if type is not UNSET:
            field_dict["type"] = type
        if affectedness is not UNSET:
            field_dict["affectedness"] = affectedness
        if resolution is not UNSET:
            field_dict["resolution"] = resolution
        if ps_module is not UNSET:
            field_dict["ps_module"] = ps_module
        if ps_component is not UNSET:
            field_dict["ps_component"] = ps_component
        if statement is not UNSET:
            field_dict["statement"] = statement
        if impact is not UNSET:
            field_dict["impact"] = impact
        if cvss2 is not UNSET:
            field_dict["cvss2"] = cvss2
        if cvss2_score is not UNSET:
            field_dict["cvss2_score"] = cvss2_score
        if cvss3 is not UNSET:
            field_dict["cvss3"] = cvss3
        if cvss3_score is not UNSET:
            field_dict["cvss3_score"] = cvss3_score

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        uuid = d.pop("uuid", UNSET)

        trackers = []
        _trackers = d.pop("trackers", UNSET)
        if _trackers is UNSET:
            trackers = UNSET
        else:
            for trackers_item_data in _trackers or []:
                _trackers_item = trackers_item_data
                trackers_item: Tracker
                if isinstance(_trackers_item, Unset):
                    trackers_item = UNSET
                else:
                    trackers_item = Tracker.from_dict(_trackers_item)

                trackers.append(trackers_item)

        def _parse_type(data: object) -> Union[AffectTypeEnum, None, Unset]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, str):
                    raise TypeError()
                _type_type_0 = data
                type_type_0: Union[Unset, AffectTypeEnum]
                if isinstance(_type_type_0, Unset):
                    type_type_0 = UNSET
                else:
                    type_type_0 = AffectTypeEnum(_type_type_0)

                return type_type_0
            except:  # noqa: E722
                pass
            return cast(Union[AffectTypeEnum, None, Unset], data)

        type = _parse_type(d.pop("type", UNSET))

        def _parse_affectedness(data: object) -> Union[AffectednessEnum, None, Unset]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, str):
                    raise TypeError()
                _affectedness_type_0 = data
                affectedness_type_0: Union[Unset, AffectednessEnum]
                if isinstance(_affectedness_type_0, Unset):
                    affectedness_type_0 = UNSET
                else:
                    affectedness_type_0 = AffectednessEnum(_affectedness_type_0)

                return affectedness_type_0
            except:  # noqa: E722
                pass
            return cast(Union[AffectednessEnum, None, Unset], data)

        affectedness = _parse_affectedness(d.pop("affectedness", UNSET))

        def _parse_resolution(data: object) -> Union[None, ResolutionEnum, Unset]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, str):
                    raise TypeError()
                _resolution_type_0 = data
                resolution_type_0: Union[Unset, ResolutionEnum]
                if isinstance(_resolution_type_0, Unset):
                    resolution_type_0 = UNSET
                else:
                    resolution_type_0 = ResolutionEnum(_resolution_type_0)

                return resolution_type_0
            except:  # noqa: E722
                pass
            return cast(Union[None, ResolutionEnum, Unset], data)

        resolution = _parse_resolution(d.pop("resolution", UNSET))

        ps_module = d.pop("ps_module", UNSET)

        ps_component = d.pop("ps_component", UNSET)

        statement = d.pop("statement", UNSET)

        def _parse_impact(data: object) -> Union[BlankEnum, ImpactEnum, None, Unset]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, str):
                    raise TypeError()
                _impact_type_0 = data
                impact_type_0: Union[Unset, ImpactEnum]
                if isinstance(_impact_type_0, Unset):
                    impact_type_0 = UNSET
                else:
                    impact_type_0 = ImpactEnum(_impact_type_0)

                return impact_type_0
            except:  # noqa: E722
                pass
            try:
                if not isinstance(data, str):
                    raise TypeError()
                _impact_type_1 = data
                impact_type_1: Union[Unset, BlankEnum]
                if isinstance(_impact_type_1, Unset):
                    impact_type_1 = UNSET
                else:
                    impact_type_1 = BlankEnum(_impact_type_1)

                return impact_type_1
            except:  # noqa: E722
                pass
            return cast(Union[BlankEnum, ImpactEnum, None, Unset], data)

        impact = _parse_impact(d.pop("impact", UNSET))

        cvss2 = d.pop("cvss2", UNSET)

        cvss2_score = d.pop("cvss2_score", UNSET)

        cvss3 = d.pop("cvss3", UNSET)

        cvss3_score = d.pop("cvss3_score", UNSET)

        affect = cls(
            uuid=uuid,
            trackers=trackers,
            type=type,
            affectedness=affectedness,
            resolution=resolution,
            ps_module=ps_module,
            ps_component=ps_component,
            statement=statement,
            impact=impact,
            cvss2=cvss2,
            cvss2_score=cvss2_score,
            cvss3=cvss3,
            cvss3_score=cvss3_score,
        )

        affect.additional_properties = d
        return affect

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from setuptools import setup, find_packages

with open("README.md", "r", encoding="utf-8") as fh:
    long_description = fh.read()

setup(
    name="osidb-bindings",
    version="1.0.3",
    author="Jakub Frejlach, Red Hat Product Security",
    author_email="jfrejlac@redhat.com",
    description="Python bindings for accessing OSIDB API",
    url="https://github.com/RedHatProductSecurity/osidb-bindings",
    long_description=long_description,
    long_description_content_type="text/markdown",
    classifiers=[
        "Programming Language :: Python :: 3",
    ],
    packages=find_packages(include=["osidb_bindings", "osidb_bindings.*"]),
    python_requires=">=3.6",
    install_requires=["attrs", "httpx", "python-dateutil"],
)
